@@ -25,11 +25,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -91,8 +94,10 @@ types: list[str] = [
     "AWS::AppStream::StackFleetAssociation",
     "AWS::AppStream::StackUserAssociation",
     "AWS::AppStream::User",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -132,6 +137,7 @@ types: list[str] = [
     "AWS::Batch::SchedulingPolicy",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::ApplicationInferenceProfile",
     "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
@@ -151,13 +157,16 @@ types: list[str] = [
     "AWS::Cassandra::Table",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::Cloud9::EnvironmentEC2",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ModuleDefaultVersion",
     "AWS::CloudFormation::ModuleVersion",
@@ -185,6 +194,7 @@ types: list[str] = [
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
     "AWS::CloudTrail::Channel",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
@@ -244,6 +254,7 @@ types: list[str] = [
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
+    "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
     "AWS::Connect::Instance",
@@ -368,6 +379,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -392,6 +404,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -566,6 +580,7 @@ types: list[str] = [
     "AWS::IAM::VirtualMFADevice",
     "AWS::IVS::Channel",
     "AWS::IVS::EncoderConfiguration",
+    "AWS::IVS::IngestConfiguration",
     "AWS::IVS::PlaybackKeyPair",
     "AWS::IVS::PlaybackRestrictionPolicy",
     "AWS::IVS::PublicKey",
@@ -633,6 +648,7 @@ types: list[str] = [
     "AWS::IoTFleetWise::Fleet",
     "AWS::IoTFleetWise::ModelManifest",
     "AWS::IoTFleetWise::SignalCatalog",
+    "AWS::IoTFleetWise::StateTemplate",
     "AWS::IoTFleetWise::Vehicle",
     "AWS::IoTSiteWise::AccessPolicy",
     "AWS::IoTSiteWise::Asset",
@@ -719,6 +735,7 @@ types: list[str] = [
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -814,6 +831,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -890,6 +908,7 @@ types: list[str] = [
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -915,6 +934,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RoboMaker::Fleet",
     "AWS::RoboMaker::Robot",
     "AWS::RoboMaker::RobotApplication",
@@ -955,6 +975,8 @@ types: list[str] = [
     "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3::StorageLens",
     "AWS::S3::StorageLensGroup",
+    "AWS::S3Express::BucketPolicy",
+    "AWS::S3Express::DirectoryBucket",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
     "AWS::S3Outposts::AccessPoint",
@@ -1003,6 +1025,7 @@ types: list[str] = [
     "AWS::SSO::PermissionSet",
     "AWS::SageMaker::App",
     "AWS::SageMaker::AppImageConfig",
+    "AWS::SageMaker::Cluster",
     "AWS::SageMaker::CodeRepository",
     "AWS::SageMaker::DataQualityJobDefinition",
     "AWS::SageMaker::Domain",
@@ -1089,6 +1112,7 @@ types: list[str] = [
     "AWS::Synthetics::Canary",
     "AWS::Synthetics::Group",
     "AWS::SystemsManagerSAP::Application",
+    "AWS::Timestream::Database",
     "AWS::Timestream::InfluxDBInstance",
     "AWS::Transfer::Agreement",
     "AWS::Transfer::Certificate",
@@ -1139,6 +1163,7 @@ types: list[str] = [
     "AWS::WorkSpaces::WorkspacesPool",
     "AWS::WorkSpacesThinClient::Environment",
     "AWS::WorkSpacesWeb::BrowserSettings",
+    "AWS::WorkSpacesWeb::DataProtectionSettings",
     "AWS::WorkSpacesWeb::IdentityProvider",
     "AWS::WorkSpacesWeb::IpAccessSettings",
     "AWS::WorkSpacesWeb::NetworkSettings",
@@ -1175,11 +1200,14 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1206,6 +1234,7 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
+    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -1242,8 +1271,10 @@ cached: list[str] = [
     "aws-appstream-imagebuilder.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
@@ -1261,6 +1292,7 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1282,11 +1314,16 @@ cached: list[str] = [
     "aws-batch-schedulingpolicy.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
+    "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-datasource.json",
+    "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
+    "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
@@ -1296,13 +1333,16 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloud9-environmentec2.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-moduledefaultversion.json",
     "aws-cloudformation-moduleversion.json",
@@ -1330,6 +1370,7 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
     "aws-cloudtrail-channel.json",
+    "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
@@ -1387,7 +1428,9 @@ cached: list[str] = [
     "aws-config-storedquery.json",
     "aws-connect-agentstatus.json",
     "aws-connect-approvedorigin.json",
+    "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
+    "aws-connect-emailaddress.json",
     "aws-connect-evaluationform.json",
     "aws-connect-hoursofoperation.json",
     "aws-connect-instance.json",
@@ -1510,6 +1553,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
@@ -1540,6 +1584,8 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
@@ -1583,7 +1629,6 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1607,7 +1652,9 @@ cached: list[str] = [
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-events-apidestination.json",
     "aws-events-archive.json",
+    "aws-events-connection.json",
     "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1762,14 +1809,11 @@ cached: list[str] = [
     "aws-iotfleetwise-fleet.json",
     "aws-iotfleetwise-modelmanifest.json",
     "aws-iotfleetwise-signalcatalog.json",
+    "aws-iotfleetwise-statetemplate.json",
     "aws-iotfleetwise-vehicle.json",
-    "aws-iotsitewise-accesspolicy.json",
     "aws-iotsitewise-asset.json",
     "aws-iotsitewise-assetmodel.json",
-    "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
-    "aws-iotsitewise-portal.json",
-    "aws-iotsitewise-project.json",
     "aws-iottwinmaker-componenttype.json",
     "aws-iottwinmaker-entity.json",
     "aws-iottwinmaker-scene.json",
@@ -1777,6 +1821,7 @@ cached: list[str] = [
     "aws-iottwinmaker-workspace.json",
     "aws-ivs-channel.json",
     "aws-ivs-encoderconfiguration.json",
+    "aws-ivs-ingestconfiguration.json",
     "aws-ivs-playbackkeypair.json",
     "aws-ivs-playbackrestrictionpolicy.json",
     "aws-ivs-publickey.json",
@@ -1821,7 +1866,6 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
@@ -1854,6 +1898,8 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-m2-application.json",
+    "aws-m2-deployment.json",
     "aws-m2-environment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
@@ -1893,6 +1939,7 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
+    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediastore-container.json",
     "aws-mediatailor-channel.json",
@@ -1944,6 +1991,8 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1954,7 +2003,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-osis-pipeline.json",
     "aws-pcaconnectorad-connector.json",
@@ -2004,6 +2052,7 @@ cached: list[str] = [
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-customdbengineversion.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
@@ -2044,6 +2093,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -2078,6 +2128,8 @@ cached: list[str] = [
     "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
+    "aws-s3express-bucketpolicy.json",
+    "aws-s3express-directorybucket.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-s3outposts-accesspoint.json",
@@ -2086,6 +2138,7 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-cluster.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-domain.json",
@@ -2117,6 +2170,8 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
+    "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
@@ -2208,7 +2263,6 @@ cached: list[str] = [
     "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-systemsmanagersap-application.json",
-    "aws-timestream-influxdbinstance.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
@@ -2252,6 +2306,7 @@ cached: list[str] = [
     "aws-workspaces-workspacespool.json",
     "aws-workspacesthinclient-environment.json",
     "aws-workspacesweb-browsersettings.json",
+    "aws-workspacesweb-dataprotectionsettings.json",
     "aws-workspacesweb-identityprovider.json",
     "aws-workspacesweb-ipaccesssettings.json",
     "aws-workspacesweb-networksettings.json",
