@@ -16,11 +16,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -50,8 +53,10 @@ types: list[str] = [
     "AWS::AppConfig::Extension",
     "AWS::AppConfig::ExtensionAssociation",
     "AWS::AppConfig::HostedConfigurationVersion",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -88,18 +93,23 @@ types: list[str] = [
     "AWS::CE::AnomalyMonitor",
     "AWS::CE::AnomalySubscription",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::PublicTypeVersion",
+    "AWS::CloudFormation::Publisher",
     "AWS::CloudFormation::ResourceDefaultVersion",
     "AWS::CloudFormation::ResourceVersion",
     "AWS::CloudFormation::Stack",
     "AWS::CloudFormation::StackSet",
+    "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
     "AWS::CloudFront::CachePolicy",
@@ -115,7 +125,9 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
+    "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
     "AWS::CloudWatch::Alarm",
     "AWS::CloudWatch::AnomalyDetector",
@@ -220,6 +232,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -244,6 +257,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -505,6 +520,7 @@ types: list[str] = [
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -519,6 +535,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
@@ -620,6 +637,7 @@ types: list[str] = [
     "AWS::StepFunctions::StateMachineAlias",
     "AWS::StepFunctions::StateMachineVersion",
     "AWS::Synthetics::Canary",
+    "AWS::SystemsManagerSAP::Application",
     "AWS::Transfer::Agreement",
     "AWS::Transfer::Certificate",
     "AWS::Transfer::Connector",
@@ -675,15 +693,19 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -702,6 +724,7 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
+    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -710,8 +733,10 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-servicelevelobjective.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
@@ -724,6 +749,7 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
@@ -738,18 +764,23 @@ cached: list[str] = [
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-publictypeversion.json",
+    "aws-cloudformation-publisher.json",
     "aws-cloudformation-resourcedefaultversion.json",
     "aws-cloudformation-resourceversion.json",
     "aws-cloudformation-stack.json",
     "aws-cloudformation-stackset.json",
+    "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
@@ -764,7 +795,9 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
+    "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
@@ -823,7 +856,6 @@ cached: list[str] = [
     "aws-dms-migrationproject.json",
     "aws-dms-replicationconfig.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
@@ -861,6 +893,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
@@ -882,8 +915,11 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
@@ -922,7 +958,6 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
-    "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
@@ -978,6 +1013,7 @@ cached: list[str] = [
     "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -990,11 +1026,13 @@ cached: list[str] = [
     "aws-iam-usertogroupaddition.json",
     "aws-identitystore-group.json",
     "aws-identitystore-groupmembership.json",
+    "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
     "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
+    "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
     "aws-internetmonitor-monitor.json",
@@ -1018,7 +1056,6 @@ cached: list[str] = [
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1047,6 +1084,7 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
+    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediatailor-channel.json",
     "aws-mediatailor-channelpolicy.json",
@@ -1088,7 +1126,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
@@ -1096,6 +1133,7 @@ cached: list[str] = [
     "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
@@ -1124,6 +1162,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -1161,6 +1200,8 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
+    "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
@@ -1218,6 +1259,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
     "aws-synthetics-canary.json",
+    "aws-systemsmanagersap-application.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
