@@ -53,9 +53,11 @@ types: list[str] = [
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ResourceDefaultVersion",
     "AWS::CloudFormation::ResourceVersion",
@@ -120,6 +122,13 @@ types: list[str] = [
     "AWS::EC2::FlowLog",
     "AWS::EC2::GatewayRouteTableAssociation",
     "AWS::EC2::Host",
+    "AWS::EC2::IPAM",
+    "AWS::EC2::IPAMAllocation",
+    "AWS::EC2::IPAMPool",
+    "AWS::EC2::IPAMPoolCidr",
+    "AWS::EC2::IPAMResourceDiscovery",
+    "AWS::EC2::IPAMResourceDiscoveryAssociation",
+    "AWS::EC2::IPAMScope",
     "AWS::EC2::Instance",
     "AWS::EC2::InternetGateway",
     "AWS::EC2::KeyPair",
@@ -137,6 +146,8 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
+    "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
     "AWS::EC2::SubnetCidrBlock",
@@ -156,6 +167,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -174,6 +187,7 @@ types: list[str] = [
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
+    "AWS::ECR::RepositoryCreationTemplate",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
@@ -201,6 +215,7 @@ types: list[str] = [
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
     "AWS::ElastiCache::SecurityGroupIngress",
+    "AWS::ElastiCache::ServerlessCache",
     "AWS::ElastiCache::SubnetGroup",
     "AWS::ElastiCache::User",
     "AWS::ElastiCache::UserGroup",
@@ -220,6 +235,12 @@ types: list[str] = [
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
     "AWS::GameLift::Fleet",
+    "AWS::GuardDuty::Detector",
+    "AWS::GuardDuty::Filter",
+    "AWS::GuardDuty::IPSet",
+    "AWS::GuardDuty::Master",
+    "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -235,6 +256,8 @@ types: list[str] = [
     "AWS::IAM::User",
     "AWS::IAM::UserPolicy",
     "AWS::IAM::UserToGroupAddition",
+    "AWS::IdentityStore::Group",
+    "AWS::IdentityStore::GroupMembership",
     "AWS::ImageBuilder::Component",
     "AWS::ImageBuilder::ContainerRecipe",
     "AWS::ImageBuilder::DistributionConfiguration",
@@ -257,6 +280,10 @@ types: list[str] = [
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
     "AWS::KinesisFirehose::DeliveryStream",
+    "AWS::LakeFormation::DataCellsFilter",
+    "AWS::LakeFormation::PrincipalPermissions",
+    "AWS::LakeFormation::Tag",
+    "AWS::LakeFormation::TagAssociation",
     "AWS::Lambda::Alias",
     "AWS::Lambda::EventInvokeConfig",
     "AWS::Lambda::EventSourceMapping",
@@ -265,6 +292,7 @@ types: list[str] = [
     "AWS::Lambda::LayerVersionPermission",
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
+    "AWS::Logs::AccountPolicy",
     "AWS::Logs::Delivery",
     "AWS::Logs::DeliveryDestination",
     "AWS::Logs::DeliverySource",
@@ -302,6 +330,7 @@ types: list[str] = [
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::OptionGroup",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -403,6 +432,7 @@ cached: list[str] = [
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
@@ -411,9 +441,11 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-certificatemanager-certificate.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-resourcedefaultversion.json",
     "aws-cloudformation-resourceversion.json",
@@ -457,7 +489,6 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
@@ -467,6 +498,13 @@ cached: list[str] = [
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
+    "aws-ec2-ipamallocation.json",
+    "aws-ec2-ipampool.json",
+    "aws-ec2-ipampoolcidr.json",
+    "aws-ec2-ipamresourcediscovery.json",
+    "aws-ec2-ipamresourcediscoveryassociation.json",
+    "aws-ec2-ipamscope.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
@@ -480,6 +518,8 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
+    "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetroutetableassociation.json",
@@ -496,10 +536,16 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
+    "aws-ec2-vpcendpointconnectionnotification.json",
+    "aws-ec2-vpcendpointservice.json",
+    "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcpeeringconnection.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
@@ -509,6 +555,7 @@ cached: list[str] = [
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
+    "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
@@ -529,8 +576,8 @@ cached: list[str] = [
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
@@ -541,6 +588,12 @@ cached: list[str] = [
     "aws-emr-instancegroupconfig.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
+    "aws-guardduty-detector.json",
+    "aws-guardduty-filter.json",
+    "aws-guardduty-ipset.json",
+    "aws-guardduty-master.json",
+    "aws-guardduty-member.json",
+    "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -555,6 +608,8 @@ cached: list[str] = [
     "aws-iam-user.json",
     "aws-iam-userpolicy.json",
     "aws-iam-usertogroupaddition.json",
+    "aws-identitystore-group.json",
+    "aws-identitystore-groupmembership.json",
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
@@ -570,10 +625,17 @@ cached: list[str] = [
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
+    "aws-lakeformation-datacellsfilter.json",
+    "aws-lakeformation-principalpermissions.json",
+    "aws-lakeformation-tag.json",
+    "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
+    "aws-lambda-version.json",
+    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -593,10 +655,10 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
@@ -618,6 +680,7 @@ cached: list[str] = [
     "aws-redshift-scheduledaction.json",
     "aws-resourcegroups-group.json",
     "aws-route53-dnssec.json",
+    "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -633,6 +696,8 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
+    "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
@@ -668,7 +733,11 @@ cached: list[str] = [
     "aws-synthetics-canary.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
+    "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
+    "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
