@@ -22,11 +22,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -84,8 +87,10 @@ types: list[str] = [
     "AWS::AppStream::StackFleetAssociation",
     "AWS::AppStream::StackUserAssociation",
     "AWS::AppStream::User",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -125,6 +130,7 @@ types: list[str] = [
     "AWS::Batch::SchedulingPolicy",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::ApplicationInferenceProfile",
     "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
@@ -144,13 +150,16 @@ types: list[str] = [
     "AWS::Cassandra::Table",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::Cloud9::EnvironmentEC2",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ModuleDefaultVersion",
     "AWS::CloudFormation::ModuleVersion",
@@ -178,6 +187,7 @@ types: list[str] = [
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
     "AWS::CloudTrail::Channel",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
@@ -207,6 +217,7 @@ types: list[str] = [
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
     "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolDomain",
@@ -233,6 +244,7 @@ types: list[str] = [
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
+    "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
     "AWS::Connect::Instance",
@@ -254,6 +266,7 @@ types: list[str] = [
     "AWS::Connect::View",
     "AWS::Connect::ViewVersion",
     "AWS::ConnectCampaigns::Campaign",
+    "AWS::ConnectCampaignsV2::Campaign",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
@@ -262,6 +275,7 @@ types: list[str] = [
     "AWS::CustomerProfiles::EventStream",
     "AWS::CustomerProfiles::Integration",
     "AWS::CustomerProfiles::ObjectType",
+    "AWS::CustomerProfiles::SegmentDefinition",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
     "AWS::DMS::DataMigration",
@@ -373,6 +387,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -397,6 +412,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -679,6 +696,7 @@ types: list[str] = [
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -845,6 +863,7 @@ types: list[str] = [
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -868,6 +887,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
@@ -1085,15 +1105,21 @@ types: list[str] = [
     "AWS::WAFv2::RuleGroup",
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
+    "AWS::Wisdom::AIAgent",
+    "AWS::Wisdom::AIAgentVersion",
     "AWS::Wisdom::AIPrompt",
+    "AWS::Wisdom::AIPromptVersion",
     "AWS::Wisdom::Assistant",
     "AWS::Wisdom::AssistantAssociation",
     "AWS::Wisdom::KnowledgeBase",
+    "AWS::Wisdom::MessageTemplate",
+    "AWS::Wisdom::MessageTemplateVersion",
     "AWS::WorkSpaces::ConnectionAlias",
     "AWS::WorkSpaces::Workspace",
     "AWS::WorkSpaces::WorkspacesPool",
     "AWS::WorkSpacesThinClient::Environment",
     "AWS::WorkSpacesWeb::BrowserSettings",
+    "AWS::WorkSpacesWeb::DataProtectionSettings",
     "AWS::WorkSpacesWeb::IdentityProvider",
     "AWS::WorkSpacesWeb::IpAccessSettings",
     "AWS::WorkSpacesWeb::NetworkSettings",
@@ -1130,11 +1156,14 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1161,6 +1190,7 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
+    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -1192,8 +1222,10 @@ cached: list[str] = [
     "aws-appstream-fleet.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
@@ -1208,6 +1240,7 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1229,10 +1262,12 @@ cached: list[str] = [
     "aws-batch-schedulingpolicy.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
+    "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -1246,13 +1281,16 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloud9-environmentec2.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-moduledefaultversion.json",
     "aws-cloudformation-moduleversion.json",
@@ -1280,6 +1318,7 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
     "aws-cloudtrail-channel.json",
+    "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
@@ -1335,6 +1374,7 @@ cached: list[str] = [
     "aws-connect-approvedorigin.json",
     "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
+    "aws-connect-emailaddress.json",
     "aws-connect-evaluationform.json",
     "aws-connect-hoursofoperation.json",
     "aws-connect-instance.json",
@@ -1356,6 +1396,7 @@ cached: list[str] = [
     "aws-connect-view.json",
     "aws-connect-viewversion.json",
     "aws-connectcampaigns-campaign.json",
+    "aws-connectcampaignsv2-campaign.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
     "aws-controltower-landingzone.json",
@@ -1364,6 +1405,7 @@ cached: list[str] = [
     "aws-customerprofiles-eventstream.json",
     "aws-customerprofiles-integration.json",
     "aws-customerprofiles-objecttype.json",
+    "aws-customerprofiles-segmentdefinition.json",
     "aws-databrew-dataset.json",
     "aws-databrew-job.json",
     "aws-databrew-project.json",
@@ -1420,7 +1462,6 @@ cached: list[str] = [
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1461,6 +1502,7 @@ cached: list[str] = [
     "aws-ec2-networkinsightsaccessscopeanalysis.json",
     "aws-ec2-networkinsightsanalysis.json",
     "aws-ec2-networkinsightspath.json",
+    "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-networkperformancemetricsubscription.json",
@@ -1471,6 +1513,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
@@ -1501,6 +1544,8 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
@@ -1536,6 +1581,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1543,7 +1589,6 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1566,7 +1611,9 @@ cached: list[str] = [
     "aws-emr-studiosessionmapping.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-events-apidestination.json",
     "aws-events-archive.json",
+    "aws-events-connection.json",
     "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1690,12 +1737,10 @@ cached: list[str] = [
     "aws-iotevents-detectormodel.json",
     "aws-iotevents-input.json",
     "aws-iotfleethub-application.json",
-    "aws-iotsitewise-accesspolicy.json",
     "aws-iotsitewise-asset.json",
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
-    "aws-iotsitewise-portal.json",
     "aws-iotsitewise-project.json",
     "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
@@ -1727,11 +1772,11 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-lex-bot.json",
     "aws-lex-botalias.json",
@@ -1769,6 +1814,7 @@ cached: list[str] = [
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
     "aws-m2-application.json",
+    "aws-m2-deployment.json",
     "aws-m2-environment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
@@ -1866,7 +1912,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-osis-pipeline.json",
     "aws-panorama-applicationinstance.json",
@@ -1915,6 +1960,7 @@ cached: list[str] = [
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-customdbengineversion.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
@@ -1953,6 +1999,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -1998,7 +2045,6 @@ cached: list[str] = [
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
-    "aws-sagemaker-domain.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -2018,14 +2064,16 @@ cached: list[str] = [
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-project.json",
+    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
-    "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
+    "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
@@ -2161,15 +2209,21 @@ cached: list[str] = [
     "aws-wafv2-rulegroup.json",
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
+    "aws-wisdom-aiagent.json",
+    "aws-wisdom-aiagentversion.json",
     "aws-wisdom-aiprompt.json",
+    "aws-wisdom-aipromptversion.json",
     "aws-wisdom-assistant.json",
     "aws-wisdom-assistantassociation.json",
     "aws-wisdom-knowledgebase.json",
+    "aws-wisdom-messagetemplate.json",
+    "aws-wisdom-messagetemplateversion.json",
     "aws-workspaces-connectionalias.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
     "aws-workspacesthinclient-environment.json",
     "aws-workspacesweb-browsersettings.json",
+    "aws-workspacesweb-dataprotectionsettings.json",
     "aws-workspacesweb-identityprovider.json",
     "aws-workspacesweb-ipaccesssettings.json",
     "aws-workspacesweb-networksettings.json",
