@@ -16,11 +16,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -66,8 +69,10 @@ types: list[str] = [
     "AWS::AppStream::StackFleetAssociation",
     "AWS::AppStream::StackUserAssociation",
     "AWS::AppStream::User",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::FunctionConfiguration",
     "AWS::AppSync::GraphQLApi",
@@ -225,6 +230,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -249,6 +255,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -682,11 +690,14 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -712,6 +723,7 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
+    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -727,8 +739,10 @@ cached: list[str] = [
     "aws-appmesh-virtualrouter.json",
     "aws-appmesh-virtualservice.json",
     "aws-appstream-stackfleetassociation.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-datasource.json",
     "aws-appsync-functionconfiguration.json",
     "aws-appsync-graphqlschema.json",
@@ -740,7 +754,6 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -755,6 +768,7 @@ cached: list[str] = [
     "aws-batch-schedulingpolicy.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
+    "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
@@ -779,7 +793,6 @@ cached: list[str] = [
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
-    "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
@@ -836,7 +849,6 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-dhcpoptions.json",
@@ -870,6 +882,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
@@ -894,12 +907,15 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
+    "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
@@ -928,7 +944,6 @@ cached: list[str] = [
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -949,9 +964,7 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-emr-studio.json",
     "aws-emrserverless-application.json",
-    "aws-events-apidestination.json",
     "aws-events-archive.json",
-    "aws-events-connection.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -965,9 +978,7 @@ cached: list[str] = [
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
-    "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
-    "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-matchmakingconfiguration.json",
@@ -1000,6 +1011,7 @@ cached: list[str] = [
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -1065,10 +1077,10 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1109,7 +1121,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
@@ -1149,7 +1160,6 @@ cached: list[str] = [
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53resolver-firewalldomainlist.json",
-    "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
@@ -1158,6 +1168,9 @@ cached: list[str] = [
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
     "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
+    "aws-s3-accessgrant.json",
+    "aws-s3-accessgrantsinstance.json",
+    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -1187,6 +1200,8 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
+    "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
@@ -1236,6 +1251,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
+    "aws-synthetics-canary.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
