@@ -16,11 +16,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -50,8 +53,17 @@ types: list[str] = [
     "AWS::AppConfig::Extension",
     "AWS::AppConfig::ExtensionAssociation",
     "AWS::AppConfig::HostedConfigurationVersion",
+    "AWS::AppMesh::GatewayRoute",
+    "AWS::AppMesh::Mesh",
+    "AWS::AppMesh::Route",
+    "AWS::AppMesh::VirtualGateway",
+    "AWS::AppMesh::VirtualNode",
+    "AWS::AppMesh::VirtualRouter",
+    "AWS::AppMesh::VirtualService",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -83,22 +95,34 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Bedrock::Flow",
+    "AWS::Bedrock::FlowAlias",
+    "AWS::Bedrock::FlowVersion",
+    "AWS::Bedrock::Guardrail",
+    "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::Prompt",
+    "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
     "AWS::CE::AnomalyMonitor",
     "AWS::CE::AnomalySubscription",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::PublicTypeVersion",
+    "AWS::CloudFormation::Publisher",
     "AWS::CloudFormation::ResourceDefaultVersion",
     "AWS::CloudFormation::ResourceVersion",
     "AWS::CloudFormation::Stack",
     "AWS::CloudFormation::StackSet",
+    "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
     "AWS::CloudFront::CachePolicy",
@@ -114,7 +138,9 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
+    "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
     "AWS::CloudWatch::Alarm",
     "AWS::CloudWatch::AnomalyDetector",
@@ -138,7 +164,9 @@ types: list[str] = [
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolResourceServer",
     "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUICustomizationAttachment",
     "AWS::Cognito::UserPoolUser",
     "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
@@ -149,11 +177,13 @@ types: list[str] = [
     "AWS::Config::DeliveryChannel",
     "AWS::Config::OrganizationConfigRule",
     "AWS::Config::OrganizationConformancePack",
+    "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::InstanceProfile",
     "AWS::DMS::MigrationProject",
@@ -216,6 +246,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -240,6 +271,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -283,6 +316,7 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
+    "AWS::EMRContainers::VirtualCluster",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::ParameterGroup",
     "AWS::ElastiCache::ReplicationGroup",
@@ -344,6 +378,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
@@ -390,6 +425,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
@@ -433,8 +469,28 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
+    "AWS::NetworkManager::CustomerGatewayAssociation",
+    "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::GlobalNetwork",
+    "AWS::NetworkManager::Link",
+    "AWS::NetworkManager::LinkAssociation",
+    "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
+    "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::OpenSearchServerless::AccessPolicy",
+    "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::LifecyclePolicy",
+    "AWS::OpenSearchServerless::SecurityConfig",
+    "AWS::OpenSearchServerless::SecurityPolicy",
+    "AWS::OpenSearchServerless::VpcEndpoint",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -453,11 +509,14 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pipes::Pipe",
     "AWS::QuickSight::Analysis",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::Folder",
     "AWS::QuickSight::RefreshSchedule",
     "AWS::QuickSight::Template",
     "AWS::QuickSight::Theme",
@@ -479,6 +538,7 @@ types: list[str] = [
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -487,6 +547,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -494,6 +555,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
@@ -545,8 +607,13 @@ types: list[str] = [
     "AWS::SSO::Instance",
     "AWS::SSO::InstanceAccessControlAttributeConfiguration",
     "AWS::SSO::PermissionSet",
+    "AWS::SageMaker::FeatureGroup",
+    "AWS::SageMaker::Image",
+    "AWS::SageMaker::ImageVersion",
     "AWS::SageMaker::MlflowTrackingServer",
     "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::ModelPackage",
+    "AWS::SageMaker::ModelPackageGroup",
     "AWS::Scheduler::Schedule",
     "AWS::Scheduler::ScheduleGroup",
     "AWS::SecretsManager::ResourcePolicy",
@@ -595,6 +662,7 @@ types: list[str] = [
     "AWS::StepFunctions::StateMachineAlias",
     "AWS::StepFunctions::StateMachineVersion",
     "AWS::Synthetics::Canary",
+    "AWS::SystemsManagerSAP::Application",
     "AWS::Transfer::Agreement",
     "AWS::Transfer::Certificate",
     "AWS::Transfer::Connector",
@@ -606,6 +674,16 @@ types: list[str] = [
     "AWS::VerifiedPermissions::Policy",
     "AWS::VerifiedPermissions::PolicyStore",
     "AWS::VerifiedPermissions::PolicyTemplate",
+    "AWS::VpcLattice::AccessLogSubscription",
+    "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourcePolicy",
+    "AWS::VpcLattice::Rule",
+    "AWS::VpcLattice::Service",
+    "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkServiceAssociation",
+    "AWS::VpcLattice::ServiceNetworkVpcAssociation",
+    "AWS::VpcLattice::TargetGroup",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -636,7 +714,28 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-apigateway-account.json",
+    "aws-apigateway-apikey.json",
+    "aws-apigateway-authorizer.json",
+    "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
+    "aws-apigateway-clientcertificate.json",
+    "aws-apigateway-deployment.json",
+    "aws-apigateway-documentationpart.json",
+    "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
+    "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
+    "aws-apigateway-model.json",
+    "aws-apigateway-requestvalidator.json",
+    "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
+    "aws-apigateway-stage.json",
+    "aws-apigateway-usageplan.json",
+    "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
@@ -656,16 +755,23 @@ cached: list[str] = [
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalabletarget.json",
-    "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-servicelevelobjective.json",
+    "aws-appmesh-gatewayroute.json",
+    "aws-appmesh-mesh.json",
+    "aws-appmesh-route.json",
+    "aws-appmesh-virtualgateway.json",
+    "aws-appmesh-virtualnode.json",
+    "aws-appmesh-virtualrouter.json",
+    "aws-appmesh-virtualservice.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -690,21 +796,33 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-bedrock-flow.json",
+    "aws-bedrock-flowalias.json",
+    "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
+    "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-publictypeversion.json",
+    "aws-cloudformation-publisher.json",
     "aws-cloudformation-resourcedefaultversion.json",
     "aws-cloudformation-resourceversion.json",
     "aws-cloudformation-stack.json",
     "aws-cloudformation-stackset.json",
+    "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
@@ -719,13 +837,16 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
+    "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
+    "aws-cloudwatch-metricstream.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -741,7 +862,9 @@ cached: list[str] = [
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolresourceserver.json",
     "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluicustomizationattachment.json",
     "aws-cognito-userpooluser.json",
     "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-aggregationauthorization.json",
@@ -752,6 +875,7 @@ cached: list[str] = [
     "aws-config-deliverychannel.json",
     "aws-config-organizationconfigrule.json",
     "aws-config-organizationconformancepack.json",
+    "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
@@ -769,12 +893,12 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
     "aws-dms-replicationconfig.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
@@ -791,6 +915,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -801,18 +926,21 @@ cached: list[str] = [
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
-    "aws-ec2-networkinterface.json",
+    "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkperformancemetricsubscription.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
     "aws-ec2-routetable.json",
+    "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
+    "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
@@ -834,16 +962,18 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
-    "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
-    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
@@ -873,7 +1003,6 @@ cached: list[str] = [
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
@@ -889,9 +1018,9 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
+    "aws-emrcontainers-virtualcluster.json",
     "aws-events-apidestination.json",
     "aws-events-archive.json",
-    "aws-events-connection.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -915,6 +1044,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -923,6 +1053,8 @@ cached: list[str] = [
     "aws-glue-partition.json",
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
+    "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -934,6 +1066,7 @@ cached: list[str] = [
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -958,10 +1091,13 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
+    "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -972,10 +1108,10 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1000,9 +1136,27 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
+    "aws-networkmanager-customergatewayassociation.json",
+    "aws-networkmanager-device.json",
+    "aws-networkmanager-globalnetwork.json",
+    "aws-networkmanager-link.json",
+    "aws-networkmanager-linkassociation.json",
+    "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
+    "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
+    "aws-opensearchserverless-accesspolicy.json",
+    "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securitypolicy.json",
+    "aws-opensearchserverless-vpcendpoint.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -1010,24 +1164,24 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
-    "aws-pcaconnectorad-connector.json",
-    "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
-    "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-quicksight-analysis.json",
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
+    "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
@@ -1039,6 +1193,7 @@ cached: list[str] = [
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
+    "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
@@ -1049,6 +1204,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1056,6 +1212,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -1086,20 +1243,27 @@ cached: list[str] = [
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-featuregroup.json",
+    "aws-sagemaker-image.json",
+    "aws-sagemaker-imageversion.json",
     "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-modelpackage.json",
+    "aws-sagemaker-modelpackagegroup.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-productsubscription.json",
+    "aws-securityhub-securitycontrol.json",
     "aws-securityhub-standard.json",
     "aws-servicecatalog-cloudformationproduct.json",
     "aws-servicecatalog-cloudformationprovisionedproduct.json",
@@ -1150,6 +1314,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
     "aws-synthetics-canary.json",
+    "aws-systemsmanagersap-application.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
@@ -1161,6 +1326,16 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
+    "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
+    "aws-vpclattice-rule.json",
+    "aws-vpclattice-service.json",
+    "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkserviceassociation.json",
+    "aws-vpclattice-servicenetworkvpcassociation.json",
+    "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
