@@ -25,11 +25,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -68,8 +71,10 @@ types: list[str] = [
     "AWS::AppMesh::VirtualNode",
     "AWS::AppMesh::VirtualRouter",
     "AWS::AppMesh::VirtualService",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -115,6 +120,7 @@ types: list[str] = [
     "AWS::Cassandra::Table",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CleanRooms::AnalysisTemplate",
@@ -126,9 +132,11 @@ types: list[str] = [
     "AWS::CleanRoomsML::TrainingDataset",
     "AWS::Cloud9::EnvironmentEC2",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ModuleDefaultVersion",
     "AWS::CloudFormation::ModuleVersion",
@@ -156,6 +164,7 @@ types: list[str] = [
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
     "AWS::CloudTrail::Channel",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
@@ -190,6 +199,7 @@ types: list[str] = [
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
     "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolDomain",
@@ -317,6 +327,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -341,6 +352,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -389,6 +402,7 @@ types: list[str] = [
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
     "AWS::EMR::WALWorkspace",
+    "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
@@ -739,12 +753,14 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -767,6 +783,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
@@ -1012,11 +1029,14 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1059,8 +1079,10 @@ cached: list[str] = [
     "aws-appmesh-virtualnode.json",
     "aws-appmesh-virtualrouter.json",
     "aws-appmesh-virtualservice.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
@@ -1078,6 +1100,7 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1103,6 +1126,7 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cleanrooms-analysistemplate.json",
@@ -1114,9 +1138,11 @@ cached: list[str] = [
     "aws-cleanroomsml-trainingdataset.json",
     "aws-cloud9-environmentec2.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-moduledefaultversion.json",
     "aws-cloudformation-moduleversion.json",
@@ -1143,6 +1169,7 @@ cached: list[str] = [
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudtrail-channel.json",
+    "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
@@ -1251,7 +1278,6 @@ cached: list[str] = [
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnauthorizationrule.json",
@@ -1301,6 +1327,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
@@ -1331,6 +1358,8 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
@@ -1373,7 +1402,6 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1395,8 +1423,11 @@ cached: list[str] = [
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
     "aws-emr-walworkspace.json",
+    "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-events-apidestination.json",
     "aws-events-archive.json",
+    "aws-events-connection.json",
     "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1496,7 +1527,6 @@ cached: list[str] = [
     "aws-iot-certificateprovider.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
-    "aws-iot-domainconfiguration.json",
     "aws-iot-fleetmetric.json",
     "aws-iot-jobtemplate.json",
     "aws-iot-logging.json",
@@ -1541,11 +1571,11 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
@@ -1618,6 +1648,7 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
+    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediastore-container.json",
     "aws-mediatailor-channel.json",
@@ -1661,9 +1692,9 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-networkmanager-transitgatewayroutetableattachment.json",
     "aws-networkmanager-vpcattachment.json",
-    "aws-nimblestudio-studio.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1674,8 +1705,8 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-pcaconnectorscep-challenge.json",
@@ -1692,6 +1723,7 @@ cached: list[str] = [
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-customdbengineversion.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
@@ -1702,6 +1734,7 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
@@ -1718,7 +1751,6 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
-    "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
     "aws-refactorspaces-route.json",
@@ -1729,6 +1761,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -1773,14 +1806,13 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
-    "aws-sagemaker-cluster.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
+    "aws-sagemaker-domain.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
-    "aws-sagemaker-inferencecomponent.json",
     "aws-sagemaker-inferenceexperiment.json",
     "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-model.json",
@@ -1804,6 +1836,8 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
+    "aws-secretsmanager-secret.json",
+    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
