@@ -25,11 +25,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -92,8 +95,10 @@ types: list[str] = [
     "AWS::AppStream::StackFleetAssociation",
     "AWS::AppStream::StackUserAssociation",
     "AWS::AppStream::User",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -122,6 +127,7 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Backup::Framework",
+    "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Backup::ReportPlan",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
@@ -130,10 +136,18 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Bedrock::Agent",
+    "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::ApplicationInferenceProfile",
     "AWS::Bedrock::DataSource",
+    "AWS::Bedrock::Flow",
+    "AWS::Bedrock::FlowAlias",
+    "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
     "AWS::Bedrock::KnowledgeBase",
+    "AWS::Bedrock::Prompt",
+    "AWS::Bedrock::PromptVersion",
     "AWS::Budgets::Budget",
     "AWS::Budgets::BudgetsAction",
     "AWS::CDK::Metadata",
@@ -144,6 +158,7 @@ types: list[str] = [
     "AWS::Cassandra::Table",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CleanRooms::AnalysisTemplate",
@@ -157,9 +172,11 @@ types: list[str] = [
     "AWS::CleanRoomsML::TrainingDataset",
     "AWS::Cloud9::EnvironmentEC2",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ModuleDefaultVersion",
     "AWS::CloudFormation::ModuleVersion",
@@ -187,6 +204,7 @@ types: list[str] = [
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
     "AWS::CloudTrail::Channel",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
@@ -243,9 +261,11 @@ types: list[str] = [
     "AWS::Config::OrganizationConformancePack",
     "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
+    "AWS::Connect::AgentStatus",
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
+    "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
     "AWS::Connect::Instance",
@@ -264,9 +284,11 @@ types: list[str] = [
     "AWS::Connect::TrafficDistributionGroup",
     "AWS::Connect::User",
     "AWS::Connect::UserHierarchyGroup",
+    "AWS::Connect::UserHierarchyStructure",
     "AWS::Connect::View",
     "AWS::Connect::ViewVersion",
     "AWS::ConnectCampaigns::Campaign",
+    "AWS::ConnectCampaignsV2::Campaign",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
@@ -275,11 +297,13 @@ types: list[str] = [
     "AWS::CustomerProfiles::EventStream",
     "AWS::CustomerProfiles::Integration",
     "AWS::CustomerProfiles::ObjectType",
+    "AWS::CustomerProfiles::SegmentDefinition",
     "AWS::DAX::Cluster",
     "AWS::DAX::ParameterGroup",
     "AWS::DAX::SubnetGroup",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::Endpoint",
     "AWS::DMS::EventSubscription",
@@ -313,6 +337,7 @@ types: list[str] = [
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
@@ -387,6 +412,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -411,6 +437,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -541,6 +569,7 @@ types: list[str] = [
     "AWS::Glue::Table",
     "AWS::Glue::TableOptimizer",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::Grafana::Workspace",
     "AWS::Greengrass::ConnectorDefinition",
@@ -568,6 +597,7 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::HealthLake::FHIRDatastore",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -645,6 +675,7 @@ types: list[str] = [
     "AWS::Kendra::DataSource",
     "AWS::Kendra::Faq",
     "AWS::Kendra::Index",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalytics::Application",
@@ -740,9 +771,18 @@ types: list[str] = [
     "AWS::MediaConvert::Preset",
     "AWS::MediaConvert::Queue",
     "AWS::MediaLive::Channel",
+    "AWS::MediaLive::ChannelPlacementGroup",
+    "AWS::MediaLive::CloudWatchAlarmTemplate",
+    "AWS::MediaLive::CloudWatchAlarmTemplateGroup",
+    "AWS::MediaLive::Cluster",
+    "AWS::MediaLive::EventBridgeRuleTemplate",
+    "AWS::MediaLive::EventBridgeRuleTemplateGroup",
     "AWS::MediaLive::InputSecurityGroup",
     "AWS::MediaLive::Multiplex",
     "AWS::MediaLive::Multiplexprogram",
+    "AWS::MediaLive::Network",
+    "AWS::MediaLive::SdiSource",
+    "AWS::MediaLive::SignalMap",
     "AWS::MediaPackage::Asset",
     "AWS::MediaPackage::Channel",
     "AWS::MediaPackage::OriginEndpoint",
@@ -805,6 +845,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -823,6 +864,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pinpoint::ADMChannel",
     "AWS::Pinpoint::APNSChannel",
     "AWS::Pinpoint::APNSSandboxChannel",
@@ -852,6 +895,7 @@ types: list[str] = [
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::Folder",
     "AWS::QuickSight::RefreshSchedule",
     "AWS::QuickSight::Template",
     "AWS::QuickSight::Theme",
@@ -875,6 +919,7 @@ types: list[str] = [
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -883,6 +928,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -898,6 +944,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
@@ -971,6 +1018,7 @@ types: list[str] = [
     "AWS::SSMContacts::Rotation",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
+    "AWS::SSMQuickSetup::ConfigurationManager",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -979,6 +1027,7 @@ types: list[str] = [
     "AWS::SSO::PermissionSet",
     "AWS::SageMaker::App",
     "AWS::SageMaker::AppImageConfig",
+    "AWS::SageMaker::Cluster",
     "AWS::SageMaker::CodeRepository",
     "AWS::SageMaker::DataQualityJobDefinition",
     "AWS::SageMaker::Domain",
@@ -1114,14 +1163,21 @@ types: list[str] = [
     "AWS::WAFv2::RuleGroup",
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
+    "AWS::Wisdom::AIAgent",
+    "AWS::Wisdom::AIAgentVersion",
+    "AWS::Wisdom::AIPrompt",
+    "AWS::Wisdom::AIPromptVersion",
     "AWS::Wisdom::Assistant",
     "AWS::Wisdom::AssistantAssociation",
     "AWS::Wisdom::KnowledgeBase",
+    "AWS::Wisdom::MessageTemplate",
+    "AWS::Wisdom::MessageTemplateVersion",
     "AWS::WorkSpaces::ConnectionAlias",
     "AWS::WorkSpaces::Workspace",
     "AWS::WorkSpaces::WorkspacesPool",
     "AWS::WorkSpacesThinClient::Environment",
     "AWS::WorkSpacesWeb::BrowserSettings",
+    "AWS::WorkSpacesWeb::DataProtectionSettings",
     "AWS::WorkSpacesWeb::IdentityProvider",
     "AWS::WorkSpacesWeb::IpAccessSettings",
     "AWS::WorkSpacesWeb::NetworkSettings",
@@ -1157,11 +1213,14 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1184,6 +1243,7 @@ cached: list[str] = [
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
     "aws-apigatewayv2-stage.json",
+    "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
@@ -1213,6 +1273,7 @@ cached: list[str] = [
     "aws-apprunner-observabilityconfiguration.json",
     "aws-apprunner-service.json",
     "aws-apprunner-vpcconnector.json",
+    "aws-apprunner-vpcingressconnection.json",
     "aws-appstream-appblock.json",
     "aws-appstream-appblockbuilder.json",
     "aws-appstream-application.json",
@@ -1223,13 +1284,14 @@ cached: list[str] = [
     "aws-appstream-fleet.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1254,6 +1316,7 @@ cached: list[str] = [
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
+    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
@@ -1262,10 +1325,18 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-bedrock-agent.json",
+    "aws-bedrock-agentalias.json",
+    "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-datasource.json",
+    "aws-bedrock-flow.json",
+    "aws-bedrock-flowalias.json",
+    "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
@@ -1275,6 +1346,7 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cleanrooms-analysistemplate.json",
@@ -1288,9 +1360,11 @@ cached: list[str] = [
     "aws-cleanroomsml-trainingdataset.json",
     "aws-cloud9-environmentec2.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-moduledefaultversion.json",
     "aws-cloudformation-moduleversion.json",
@@ -1318,6 +1392,8 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
     "aws-cloudtrail-channel.json",
+    "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -1373,9 +1449,11 @@ cached: list[str] = [
     "aws-config-organizationconformancepack.json",
     "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
+    "aws-connect-agentstatus.json",
     "aws-connect-approvedorigin.json",
     "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
+    "aws-connect-emailaddress.json",
     "aws-connect-evaluationform.json",
     "aws-connect-hoursofoperation.json",
     "aws-connect-instance.json",
@@ -1394,9 +1472,11 @@ cached: list[str] = [
     "aws-connect-trafficdistributiongroup.json",
     "aws-connect-user.json",
     "aws-connect-userhierarchygroup.json",
+    "aws-connect-userhierarchystructure.json",
     "aws-connect-view.json",
     "aws-connect-viewversion.json",
     "aws-connectcampaigns-campaign.json",
+    "aws-connectcampaignsv2-campaign.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
     "aws-controltower-landingzone.json",
@@ -1405,6 +1485,7 @@ cached: list[str] = [
     "aws-customerprofiles-eventstream.json",
     "aws-customerprofiles-integration.json",
     "aws-customerprofiles-objecttype.json",
+    "aws-customerprofiles-segmentdefinition.json",
     "aws-databrew-dataset.json",
     "aws-databrew-job.json",
     "aws-databrew-project.json",
@@ -1428,6 +1509,7 @@ cached: list[str] = [
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
     "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-groupprofile.json",
@@ -1447,6 +1529,7 @@ cached: list[str] = [
     "aws-directoryservice-microsoftad.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-certificate.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-endpoint.json",
     "aws-dms-eventsubscription.json",
@@ -1463,7 +1546,6 @@ cached: list[str] = [
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1484,6 +1566,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1514,6 +1597,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
@@ -1544,6 +1628,9 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1578,6 +1665,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1585,7 +1673,6 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1613,7 +1700,9 @@ cached: list[str] = [
     "aws-entityresolution-matchingworkflow.json",
     "aws-entityresolution-policystatement.json",
     "aws-entityresolution-schemamapping.json",
+    "aws-events-apidestination.json",
     "aws-events-archive.json",
+    "aws-events-connection.json",
     "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1649,6 +1738,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -1663,6 +1753,7 @@ cached: list[str] = [
     "aws-glue-table.json",
     "aws-glue-tableoptimizer.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-grafana-workspace.json",
     "aws-greengrass-connectordefinition.json",
@@ -1690,6 +1781,7 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-threatintelset.json",
+    "aws-healthlake-fhirdatastore.json",
     "aws-iam-accesskey.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
@@ -1764,6 +1856,7 @@ cached: list[str] = [
     "aws-kendra-datasource.json",
     "aws-kendra-faq.json",
     "aws-kendra-index.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-application.json",
@@ -1778,6 +1871,7 @@ cached: list[str] = [
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -1794,7 +1888,6 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-lex-bot.json",
     "aws-lex-botalias.json",
@@ -1812,6 +1905,7 @@ cached: list[str] = [
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
+    "aws-location-apikey.json",
     "aws-location-geofencecollection.json",
     "aws-location-map.json",
     "aws-location-placeindex.json",
@@ -1851,8 +1945,17 @@ cached: list[str] = [
     "aws-mediaconvert-preset.json",
     "aws-mediaconvert-queue.json",
     "aws-medialive-channel.json",
+    "aws-medialive-channelplacementgroup.json",
+    "aws-medialive-cloudwatchalarmtemplate.json",
+    "aws-medialive-cloudwatchalarmtemplategroup.json",
+    "aws-medialive-cluster.json",
+    "aws-medialive-eventbridgeruletemplate.json",
+    "aws-medialive-eventbridgeruletemplategroup.json",
     "aws-medialive-multiplex.json",
     "aws-medialive-multiplexprogram.json",
+    "aws-medialive-network.json",
+    "aws-medialive-sdisource.json",
+    "aws-medialive-signalmap.json",
     "aws-mediapackage-asset.json",
     "aws-mediapackage-channel.json",
     "aws-mediapackage-originendpoint.json",
@@ -1873,6 +1976,7 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
+    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
@@ -1906,11 +2010,12 @@ cached: list[str] = [
     "aws-nimblestudio-launchprofile.json",
     "aws-nimblestudio-streamingimage.json",
     "aws-nimblestudio-studio.json",
-    "aws-nimblestudio-studiocomponent.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-omics-annotationstore.json",
+    "aws-omics-referencestore.json",
     "aws-omics-rungroup.json",
+    "aws-omics-sequencestore.json",
     "aws-omics-variantstore.json",
     "aws-omics-workflow.json",
     "aws-opensearchserverless-accesspolicy.json",
@@ -1919,6 +2024,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1930,7 +2036,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-osis-pipeline.json",
     "aws-pcaconnectorad-connector.json",
@@ -1938,6 +2043,8 @@ cached: list[str] = [
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-pinpoint-apnschannel.json",
     "aws-pinpoint-apnssandboxchannel.json",
     "aws-pinpoint-apnsvoipchannel.json",
@@ -1960,9 +2067,9 @@ cached: list[str] = [
     "aws-qldb-ledger.json",
     "aws-qldb-stream.json",
     "aws-quicksight-analysis.json",
-    "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
+    "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
@@ -1970,6 +2077,7 @@ cached: list[str] = [
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-customdbengineversion.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
@@ -1993,8 +2101,10 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
     "aws-refactorspaces-route.json",
@@ -2007,6 +2117,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -2050,10 +2161,10 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-cluster.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-domain.json",
-    "aws-sagemaker-endpoint.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -2096,6 +2207,7 @@ cached: list[str] = [
     "aws-securityhub-securitycontrol.json",
     "aws-securityhub-standard.json",
     "aws-securitylake-awslogsource.json",
+    "aws-securitylake-datalake.json",
     "aws-securitylake-subscriber.json",
     "aws-securitylake-subscribernotification.json",
     "aws-servicecatalog-acceptedportfolioshare.json",
@@ -2129,6 +2241,7 @@ cached: list[str] = [
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
     "aws-ses-receiptfilter.json",
+    "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
@@ -2159,6 +2272,7 @@ cached: list[str] = [
     "aws-ssmcontacts-rotation.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
+    "aws-ssmquicksetup-configurationmanager.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -2221,14 +2335,20 @@ cached: list[str] = [
     "aws-wafv2-rulegroup.json",
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
+    "aws-wisdom-aiagent.json",
+    "aws-wisdom-aiagentversion.json",
+    "aws-wisdom-aiprompt.json",
+    "aws-wisdom-aipromptversion.json",
     "aws-wisdom-assistant.json",
     "aws-wisdom-assistantassociation.json",
     "aws-wisdom-knowledgebase.json",
+    "aws-wisdom-messagetemplate.json",
+    "aws-wisdom-messagetemplateversion.json",
     "aws-workspaces-connectionalias.json",
     "aws-workspaces-workspace.json",
-    "aws-workspaces-workspacespool.json",
     "aws-workspacesthinclient-environment.json",
     "aws-workspacesweb-browsersettings.json",
+    "aws-workspacesweb-dataprotectionsettings.json",
     "aws-workspacesweb-identityprovider.json",
     "aws-workspacesweb-ipaccesssettings.json",
     "aws-workspacesweb-networksettings.json",
