@@ -25,11 +25,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -92,8 +95,10 @@ types: list[str] = [
     "AWS::AppStream::StackFleetAssociation",
     "AWS::AppStream::StackUserAssociation",
     "AWS::AppStream::User",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -140,6 +145,7 @@ types: list[str] = [
     "AWS::Batch::SchedulingPolicy",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::ApplicationInferenceProfile",
     "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
@@ -164,6 +170,7 @@ types: list[str] = [
     "AWS::Cassandra::Table",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CleanRooms::AnalysisTemplate",
@@ -177,9 +184,11 @@ types: list[str] = [
     "AWS::CleanRoomsML::TrainingDataset",
     "AWS::Cloud9::EnvironmentEC2",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ModuleDefaultVersion",
     "AWS::CloudFormation::ModuleVersion",
@@ -207,6 +216,7 @@ types: list[str] = [
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
     "AWS::CloudTrail::Channel",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
@@ -268,6 +278,7 @@ types: list[str] = [
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
+    "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
     "AWS::Connect::Instance",
@@ -290,6 +301,7 @@ types: list[str] = [
     "AWS::Connect::View",
     "AWS::Connect::ViewVersion",
     "AWS::ConnectCampaigns::Campaign",
+    "AWS::ConnectCampaignsV2::Campaign",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
@@ -298,6 +310,7 @@ types: list[str] = [
     "AWS::CustomerProfiles::EventStream",
     "AWS::CustomerProfiles::Integration",
     "AWS::CustomerProfiles::ObjectType",
+    "AWS::CustomerProfiles::SegmentDefinition",
     "AWS::DAX::Cluster",
     "AWS::DAX::ParameterGroup",
     "AWS::DAX::SubnetGroup",
@@ -421,6 +434,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -445,6 +459,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -562,6 +578,7 @@ types: list[str] = [
     "AWS::FraudDetector::Variable",
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
+    "AWS::GameLift::ContainerFleet",
     "AWS::GameLift::ContainerGroupDefinition",
     "AWS::GameLift::Fleet",
     "AWS::GameLift::GameServerGroup",
@@ -644,6 +661,7 @@ types: list[str] = [
     "AWS::IAM::VirtualMFADevice",
     "AWS::IVS::Channel",
     "AWS::IVS::EncoderConfiguration",
+    "AWS::IVS::IngestConfiguration",
     "AWS::IVS::PlaybackKeyPair",
     "AWS::IVS::PlaybackRestrictionPolicy",
     "AWS::IVS::PublicKey",
@@ -715,6 +733,7 @@ types: list[str] = [
     "AWS::IoTFleetWise::Fleet",
     "AWS::IoTFleetWise::ModelManifest",
     "AWS::IoTFleetWise::SignalCatalog",
+    "AWS::IoTFleetWise::StateTemplate",
     "AWS::IoTFleetWise::Vehicle",
     "AWS::IoTSiteWise::AccessPolicy",
     "AWS::IoTSiteWise::Asset",
@@ -822,6 +841,7 @@ types: list[str] = [
     "AWS::LookoutMetrics::AnomalyDetector",
     "AWS::LookoutVision::Project",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -1020,12 +1040,14 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -1051,6 +1073,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RoboMaker::Fleet",
     "AWS::RoboMaker::Robot",
     "AWS::RoboMaker::RobotApplication",
@@ -1299,15 +1322,21 @@ types: list[str] = [
     "AWS::WAFv2::RuleGroup",
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
+    "AWS::Wisdom::AIAgent",
+    "AWS::Wisdom::AIAgentVersion",
     "AWS::Wisdom::AIPrompt",
+    "AWS::Wisdom::AIPromptVersion",
     "AWS::Wisdom::Assistant",
     "AWS::Wisdom::AssistantAssociation",
     "AWS::Wisdom::KnowledgeBase",
+    "AWS::Wisdom::MessageTemplate",
+    "AWS::Wisdom::MessageTemplateVersion",
     "AWS::WorkSpaces::ConnectionAlias",
     "AWS::WorkSpaces::Workspace",
     "AWS::WorkSpaces::WorkspacesPool",
     "AWS::WorkSpacesThinClient::Environment",
     "AWS::WorkSpacesWeb::BrowserSettings",
+    "AWS::WorkSpacesWeb::DataProtectionSettings",
     "AWS::WorkSpacesWeb::IdentityProvider",
     "AWS::WorkSpacesWeb::IpAccessSettings",
     "AWS::WorkSpacesWeb::NetworkSettings",
