@@ -22,11 +22,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -75,8 +78,10 @@ types: list[str] = [
     "AWS::AppStream::StackFleetAssociation",
     "AWS::AppStream::StackUserAssociation",
     "AWS::AppStream::User",
+    "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
+    "AWS::AppSync::ChannelNamespace",
     "AWS::AppSync::DataSource",
     "AWS::AppSync::DomainName",
     "AWS::AppSync::DomainNameApiAssociation",
@@ -105,6 +110,7 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Backup::Framework",
+    "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Backup::ReportPlan",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
@@ -123,13 +129,16 @@ types: list[str] = [
     "AWS::Cassandra::Table",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
     "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::Cloud9::EnvironmentEC2",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
     "AWS::CloudFormation::HookTypeConfig",
     "AWS::CloudFormation::HookVersion",
+    "AWS::CloudFormation::LambdaHook",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ModuleDefaultVersion",
     "AWS::CloudFormation::ModuleVersion",
@@ -157,6 +166,7 @@ types: list[str] = [
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
     "AWS::CloudTrail::Channel",
+    "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
@@ -214,6 +224,7 @@ types: list[str] = [
     "AWS::DAX::SubnetGroup",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::Endpoint",
     "AWS::DMS::EventSubscription",
@@ -302,6 +313,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
+    "AWS::EC2::SecurityGroupVpcAssociation",
     "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
@@ -326,6 +338,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayRouteTablePropagation",
     "AWS::EC2::TransitGatewayVpcAttachment",
     "AWS::EC2::VPC",
+    "AWS::EC2::VPCBlockPublicAccessExclusion",
+    "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
     "AWS::EC2::VPCEndpoint",
@@ -451,6 +465,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::Greengrass::ConnectorDefinition",
     "AWS::Greengrass::ConnectorDefinitionVersion",
@@ -542,6 +557,7 @@ types: list[str] = [
     "AWS::KafkaConnect::Connector",
     "AWS::KafkaConnect::CustomPlugin",
     "AWS::KafkaConnect::WorkerConfiguration",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalytics::Application",
@@ -671,6 +687,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pipes::Pipe",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
@@ -689,6 +707,7 @@ types: list[str] = [
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
     "AWS::RUM::AppMonitor",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -697,6 +716,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -711,6 +731,7 @@ types: list[str] = [
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::ResourceGroups::TagSyncTask",
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
@@ -757,6 +778,9 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::ReceiptFilter",
+    "AWS::SES::ReceiptRule",
+    "AWS::SES::ReceiptRuleSet",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
     "AWS::SNS::Subscription",
@@ -781,6 +805,7 @@ types: list[str] = [
     "AWS::SSMContacts::Rotation",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
+    "AWS::SSMQuickSetup::ConfigurationManager",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -789,6 +814,7 @@ types: list[str] = [
     "AWS::SSO::PermissionSet",
     "AWS::SageMaker::App",
     "AWS::SageMaker::AppImageConfig",
+    "AWS::SageMaker::Cluster",
     "AWS::SageMaker::CodeRepository",
     "AWS::SageMaker::DataQualityJobDefinition",
     "AWS::SageMaker::Domain",
@@ -949,11 +975,14 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -976,6 +1005,7 @@ cached: list[str] = [
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
     "aws-apigatewayv2-stage.json",
+    "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
@@ -1000,13 +1030,13 @@ cached: list[str] = [
     "aws-appmesh-virtualservice.json",
     "aws-appstream-imagebuilder.json",
     "aws-appstream-stackfleetassociation.json",
+    "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
-    "aws-appsync-datasource.json",
+    "aws-appsync-channelnamespace.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1028,6 +1058,7 @@ cached: list[str] = [
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
+    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
@@ -1045,13 +1076,16 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloud9-environmentec2.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
     "aws-cloudformation-hookversion.json",
+    "aws-cloudformation-lambdahook.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-moduledefaultversion.json",
     "aws-cloudformation-moduleversion.json",
@@ -1079,6 +1113,8 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
     "aws-cloudtrail-channel.json",
+    "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -1160,6 +1196,7 @@ cached: list[str] = [
     "aws-directoryservice-microsoftad.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-certificate.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-endpoint.json",
     "aws-dms-eventsubscription.json",
@@ -1170,7 +1207,6 @@ cached: list[str] = [
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
     "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnauthorizationrule.json",
@@ -1190,6 +1226,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1220,6 +1257,7 @@ cached: list[str] = [
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
+    "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
@@ -1250,6 +1288,9 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpcblockpublicaccessexclusion.json",
+    "aws-ec2-vpcblockpublicaccessoptions.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1284,6 +1325,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1291,7 +1333,6 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
-    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1314,7 +1355,9 @@ cached: list[str] = [
     "aws-emr-studiosessionmapping.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-events-apidestination.json",
     "aws-events-archive.json",
+    "aws-events-connection.json",
     "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -1350,6 +1393,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -1363,6 +1407,7 @@ cached: list[str] = [
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-greengrass-connectordefinition.json",
     "aws-greengrass-connectordefinitionversion.json",
@@ -1441,6 +1486,7 @@ cached: list[str] = [
     "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
     "aws-kafkaconnect-workerconfiguration.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
@@ -1449,6 +1495,7 @@ cached: list[str] = [
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -1465,7 +1512,6 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
@@ -1510,6 +1556,7 @@ cached: list[str] = [
     "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
@@ -1517,6 +1564,7 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
+    "aws-msk-replicator.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
@@ -1555,16 +1603,18 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
@@ -1587,6 +1637,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1601,6 +1652,7 @@ cached: list[str] = [
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
@@ -1647,7 +1699,6 @@ cached: list[str] = [
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-domain.json",
-    "aws-sagemaker-endpoint.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -1722,6 +1773,9 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-receiptfilter.json",
+    "aws-ses-receiptrule.json",
+    "aws-ses-receiptruleset.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
     "aws-shield-drtaccess.json",
@@ -1751,6 +1805,7 @@ cached: list[str] = [
     "aws-ssmcontacts-rotation.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
+    "aws-ssmquicksetup-configurationmanager.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
