@@ -28,6 +28,8 @@ _N = 7
 
 _SCALAR_TYPES = (str, int, float, bool)
 
+_ACCOUNT_ID = None
+
 
 class _ResolveError(Exception):
     def __init__(self, message: str, key: Any) -> None:
@@ -368,10 +370,23 @@ class _ForEachValueFnFindInMap(_ForEachValue):
             except _ResolveError:
                 try:
                     t_map[2].value(cfn, params)
+                    max_length = -1
                     for k, v in mapping.items():
                         if isinstance(v, dict):
                             if t_map[2].value(cfn, params, only_params) in v:
+                                if (
+                                    len(v[t_map[2].value(cfn, params, only_params)])
+                                    <= max_length
+                                ):
+                                    continue
+                                if isinstance(t_map[1], _ForEachValueRef):
+                                    if t_map[1]._ref._value == "AWS::AccountId":
+                                        global _ACCOUNT_ID
+                                        _ACCOUNT_ID = k
                                 t_map[1] = _ForEachValue.create(k)
+                                max_length = len(
+                                    v[t_map[2].value(cfn, params, only_params)]
+                                )
                 except _ResolveError:
                     pass
 
@@ -439,7 +454,9 @@ class _ForEachValueRef(_ForEachValue):
             return region
 
         if v == "AWS::AccountId":
-            return account_id
+            if _ACCOUNT_ID is None:
+                raise _ResolveError("Can't resolve Fn::Ref", self._obj)
+            return _ACCOUNT_ID
 
         if v == "AWS::NotificationARNs":
             return [f"arn:{partition}:sns:{region}:{account_id}:notification"]
@@ -520,7 +537,7 @@ class _ForEachCollection:
         if self._fn:
             try:
                 values = self._fn.value(cfn, {}, False)
-                if values:
+                if values is not None:
                     if isinstance(values, list):
                         for value in values:
                             if isinstance(value, (str, dict)):
